"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.INVALID_EMAIL_WITH_BLOCKED_DOMAIN = exports.INVALID_EMAIL_DOMAIN = exports.INVALID_EMAIL = exports.INVALID_STRING_LENGTH = exports.INVALID_NUMBER = exports.INVALID_SPECIAL_SYMBOLS_AMOUNT = exports.INVALID_NUMBERS_AMOUNT = exports.INVALID_CAPITAL_LETTERS_AMOUNT = exports.FAILED_PATTERN_VALIDATION = void 0;
const FAILED_PATTERN_VALIDATION = (args) => {
    if (args.maxAmount === 0) {
        return typeof args.pattern == "string"
            ? `The string must not contain the substring "${args.pattern}".`
            : `The string must not contain a substring that satisfies the regular expression "${args.pattern}".`;
    }
    if (!args.minAmount && args.maxAmount) {
        return typeof args.pattern == "string"
            ? `The string must contain the substring "${args.pattern}" no more than ${args.maxAmount} time(s).`
            : `The string must contain a substring that satisfies the regular expression "${args.pattern}" no more than ${args.maxAmount} time(s).`;
    }
    if (args.minAmount && !args.maxAmount) {
        return typeof args.pattern == "string"
            ? `The string must contain the substring "${args.pattern}" at least ${args.minAmount} time(s).`
            : `The string must contain a substring that satisfies the regular expression "${args.pattern}" at least ${args.minAmount} time(s).`;
    }
    return typeof args.pattern == "string"
        ? `The string must contain the substring "${args.pattern}" at least ${args.minAmount} time(s) and no more than ${args.maxAmount} time(s).`
        : `The string must contain a substring that satisfies the regular expression "${args.pattern}" at least ${args.minAmount} time(s) and no more than ${args.maxAmount} time(s).`;
};
exports.FAILED_PATTERN_VALIDATION = FAILED_PATTERN_VALIDATION;
const INVALID_CAPITAL_LETTERS_AMOUNT = (args) => {
    if (args.minAmount && typeof args.maxAmount != "number") {
        return `The string must have at less ${args.minAmount} capital letter(s).`;
    }
    if (args.maxAmount && typeof args.minAmount != "number") {
        return `The string must have no more than ${args.maxAmount} capital letter(s).`;
    }
    return `The string must have at less ${args.minAmount} and no more than ${args.maxAmount} capital letter(s).`;
};
exports.INVALID_CAPITAL_LETTERS_AMOUNT = INVALID_CAPITAL_LETTERS_AMOUNT;
const INVALID_NUMBERS_AMOUNT = (args) => {
    if (args.minAmount && typeof args.maxAmount != "number") {
        return `The string must have at less ${args.minAmount} number(s).`;
    }
    if (args.maxAmount && typeof args.minAmount != "number") {
        return `The string must have no more than ${args.maxAmount} number(s).`;
    }
    return `The string must have at less ${args.minAmount} and no more than ${args.maxAmount} number(s).`;
};
exports.INVALID_NUMBERS_AMOUNT = INVALID_NUMBERS_AMOUNT;
const INVALID_SPECIAL_SYMBOLS_AMOUNT = (args) => {
    if (args.minAmount && typeof args.maxAmount != "number") {
        return `The string must have at less ${args.minAmount} special symbol(s).`;
    }
    if (args.maxAmount && typeof args.minAmount != "number") {
        return `The string must have no more than ${args.maxAmount} special symbol(s).`;
    }
    return `The string must have at less ${args.minAmount} and no more than ${args.maxAmount} special symbol(s).`;
};
exports.INVALID_SPECIAL_SYMBOLS_AMOUNT = INVALID_SPECIAL_SYMBOLS_AMOUNT;
const INVALID_NUMBER = (min, max) => {
    if (!min && max) {
        return `The number must be no more than ${max}.`;
    }
    if (min && !max) {
        return `The number must be no less than ${min}.`;
    }
    return `The number must be no less than ${min} and no more than ${max}.`;
};
exports.INVALID_NUMBER = INVALID_NUMBER;
const INVALID_STRING_LENGTH = (min, max) => {
    if (!min && max) {
        return `The length of the string must be no more than ${max}.`;
    }
    if (min && !max) {
        return `The length of the string must be no less than ${min}.`;
    }
    return `The length of the string must be no less than ${min} and no more than ${max}.`;
};
exports.INVALID_STRING_LENGTH = INVALID_STRING_LENGTH;
const INVALID_EMAIL = () => {
    return `The string is not a valid email address.`;
};
exports.INVALID_EMAIL = INVALID_EMAIL;
const INVALID_EMAIL_DOMAIN = (domains) => {
    return `The email address must contain one of the allowed domain names: ${domains.join(", ")}.`;
};
exports.INVALID_EMAIL_DOMAIN = INVALID_EMAIL_DOMAIN;
const INVALID_EMAIL_WITH_BLOCKED_DOMAIN = (domains) => {
    return `The email address must not contain the following domain names: ${domains.join(", ")}.`;
};
exports.INVALID_EMAIL_WITH_BLOCKED_DOMAIN = INVALID_EMAIL_WITH_BLOCKED_DOMAIN;
//# sourceMappingURL=messages.js.map